@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2017-01-16'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
@@ -318,6 +318,17 @@ sub _parse_raw_value {
     # should not be reached
 }
 
+sub _get_my_user_name {
+    if ($^O eq 'MSWin32') {
+        return $ENV{USERNAME};
+    } else {
+        return $ENV{USER} if $ENV{USER};
+        my @pw;
+        eval { @pw = getpwuid($>) };
+        return $pw[0] if @pw;
+    }
+}
+
 # borrowed from PERLANCAR::File::HomeDir 0.04
 sub _get_my_home_dir {
     if ($^O eq 'MSWin32') {
@@ -518,7 +529,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.31 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2017-01-13.
+This document describes version 0.32 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2017-01-16.
 
 =head1 EXPRESSION
 
@@ -743,7 +754,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Config-IOD-Reader>.
+Source repository is at L<https://github.com/perlancar/perl-Config-IOD-Reader>.
 
 =head1 BUGS
 
